==> 3.5.12-core.tar: kdepim/certmanager/lib/ui/progressdialog.h <==
/*
    progressdialog.h

    This file is part of libkleopatra, the KDE keymanagement library
    Copyright (c) 2004 Klarlvdalens Datakonsult AB

    Libkleopatra is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2 of the
    License, or (at your option) any later version.

    Libkleopatra is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

    In addition, as a special exception, the copyright holders give
    permission to link the code of this program with any edition of
    the Qt library by Trolltech AS, Norway (or with modified versions
    of Qt that use the same license as Qt), and distribute linked
    combinations including the two.  You must obey the GNU General
    Public License in all respects for all of the code used other than
    Qt.  If you modify this file, you may extend this exception to
    your version of the file, but you are not obligated to do so.  If
    you do not wish to do so, delete this exception statement from
    your version.
*/

#ifndef __KLEO_PROGRESSDIALOG_H__
#define __KLEO_PROGRESSDIALOG_H__

#include <tqprogressdialog.h>
#include <tqstring.h>
#include <kdepimmacros.h>
namespace Kleo {

  class Job;

  /**
     @short A progress dialog for Kleo::Jobs
  */
  class KDE_EXPORT ProgressDialog : public TQProgressDialog {
    Q_OBJECT
  public:
    ProgressDialog( Job * job, const TQString & baseText,
		    TQWidget * creator=0, const char * name=0, WFlags f=0  );
    ~ProgressDialog();

  public slots:
    /*! reimplementation */
    void setMinimumDuration( int ms );

  private slots:
    void slotProgress( const TQString & what, int current, int total );
    void slotDone();
  private:
    TQString mBaseText;
  };

}

#endif // __KLEO_PROGRESSDIALOG_H__

==> 3.5.13-core.tar: kdepim/certmanager/lib/ui/progressdialog.h <==
/*
    progressdialog.h

    This file is part of libkleopatra, the KDE keymanagement library
    Copyright (c) 2004 Klarlvdalens Datakonsult AB

    Libkleopatra is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2 of the
    License, or (at your option) any later version.

    Libkleopatra is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

    In addition, as a special exception, the copyright holders give
    permission to link the code of this program with any edition of
    the TQt library by Trolltech AS, Norway (or with modified versions
    of TQt that use the same license as TQt), and distribute linked
    combinations including the two.  You must obey the GNU General
    Public License in all respects for all of the code used other than
    TQt.  If you modify this file, you may extend this exception to
    your version of the file, but you are not obligated to do so.  If
    you do not wish to do so, delete this exception statement from
    your version.
*/

#ifndef __KLEO_PROGRESSDIALOG_H__
#define __KLEO_PROGRESSDIALOG_H__

#include <tqprogressdialog.h>
#include <tqstring.h>
#include <kdepimmacros.h>
namespace Kleo {

  class Job;

  /**
     @short A progress dialog for Kleo::Jobs
  */
  class KDE_EXPORT ProgressDialog : public TQProgressDialog {
    Q_OBJECT
  TQ_OBJECT
  public:
    ProgressDialog( Job * job, const TQString & baseText,
		    TQWidget * creator=0, const char * name=0, WFlags f=0  );
    ~ProgressDialog();

  public slots:
    /*! reimplementation */
    void setMinimumDuration( int ms );

  private slots:
    void slotProgress( const TQString & what, int current, int total );
    void slotDone();
  private:
    TQString mBaseText;
  };

}

#endif // __KLEO_PROGRESSDIALOG_H__
